@@ -9,7 +9,6 @@ package ast
 
 import (
 	"go/ast"
-	"strings"
 
 	"github.com/goplus/gop/token"
 )
@@ -56,99 +55,12 @@ type Decl interface {
 // Comments
 
 // A Comment node represents a single //-style 、#-style or /*-style comment.
-type Comment struct {
-	Slash token.Pos // position of "/" or # starting the comment
-	Text  string    // comment text (excluding '\n' for //-style comments)
-}
-
-// Pos returns position of first character belonging to the node.
-func (c *Comment) Pos() token.Pos { return c.Slash }
-
-// End returns position of first character immediately after the node.
-func (c *Comment) End() token.Pos { return token.Pos(int(c.Slash) + len(c.Text)) }
+type Comment = ast.Comment
 
 // A CommentGroup represents a sequence of comments
 // with no other tokens and no empty lines between.
 //
-type CommentGroup struct {
-	List []*Comment // len(List) > 0
-}
-
-// Pos returns position of first character belonging to the node.
-func (g *CommentGroup) Pos() token.Pos { return g.List[0].Pos() }
-
-// End returns position of first character immediately after the node.
-func (g *CommentGroup) End() token.Pos { return g.List[len(g.List)-1].End() }
-
-func isWhitespace(ch byte) bool { return ch == ' ' || ch == '\t' || ch == '\n' || ch == '\r' }
-
-func stripTrailingWhitespace(s string) string {
-	i := len(s)
-	for i > 0 && isWhitespace(s[i-1]) {
-		i--
-	}
-	return s[0:i]
-}
-
-// Text returns the text of the comment.
-// Comment markers (//, /*, and */), the first space of a line comment, and
-// leading and trailing empty lines are removed. Multiple empty lines are
-// reduced to one, and trailing space on lines is trimmed. Unless the result
-// is empty, it is newline-terminated.
-//
-func (g *CommentGroup) Text() string {
-	if g == nil {
-		return ""
-	}
-	comments := make([]string, len(g.List))
-	for i, c := range g.List {
-		comments[i] = c.Text
-	}
-
-	lines := make([]string, 0, 10) // most comments are less than 10 lines
-	for _, c := range comments {
-		// Remove comment markers.
-		// The parser has given us exactly the comment text.
-		switch c[1] {
-		case '/':
-			//-style comment (no newline at the end)
-			c = c[2:]
-			// strip first space - required for Example tests
-			if len(c) > 0 && c[0] == ' ' {
-				c = c[1:]
-			}
-		case '*':
-			/*-style comment */
-			c = c[2 : len(c)-2]
-		}
-
-		// Split on newlines.
-		cl := strings.Split(c, "\n")
-
-		// Walk lines, stripping trailing white space and adding to list.
-		for _, l := range cl {
-			lines = append(lines, stripTrailingWhitespace(l))
-		}
-	}
-
-	// Remove leading blank lines; convert runs of
-	// interior blank lines to a single blank line.
-	n := 0
-	for _, line := range lines {
-		if line != "" || n > 0 && lines[n-1] != "" {
-			lines[n] = line
-			n++
-		}
-	}
-	lines = lines[0:n]
-
-	// Add final "" entry to get trailing newline from Join.
-	if n > 0 && lines[n-1] != "" {
-		lines = append(lines, "")
-	}
-
-	return strings.Join(lines, "\n")
-}
+type CommentGroup = ast.CommentGroup
 
 // ----------------------------------------------------------------------------
 // Expressions and types
@@ -1188,7 +1100,7 @@ type File struct {
 	Unresolved   []*Ident        // unresolved identifiers in this file
 	Comments     []*CommentGroup // list of all comments in the source file
 	Code         []byte
-	NoEntrypoint bool // no `main` or `init` func to indicate the module entry point.
+	NoEntrypoint bool // no entrypoint func to indicate the module entry point.
 	NoPkgDecl    bool // no `package xxx` declaration
 	FileType     FileType
 }
