@@ -338,7 +338,7 @@ func nameOf(f *FuncDecl) string {
 // separator is an empty //-style comment that is interspersed between
 // different comment groups when they are concatenated into a single group
 //
-var separator = &Comment{token.NoPos, "//"}
+var separator = &Comment{Slash: token.NoPos, Text: "//"}
 
 // MergePackageFiles creates a file AST by merging the ASTs of the
 // files belonging to a package. The mode flags control merging behavior.
@@ -392,7 +392,7 @@ func MergePackageFiles(pkg *Package, mode MergeMode) *File {
 				}
 			}
 		}
-		doc = &CommentGroup{list}
+		doc = &CommentGroup{List: list}
 	}
 
 	// Collect declarations from all package files.
