@@ -454,6 +454,20 @@ func hasMethod(o types.Object, name string) bool {
 	return false
 }
 
+func getEntrypoint(ft ast.FileType, isMod bool) string {
+	switch ft {
+	case ast.FileTypeSpx:
+		return "Main"
+	case ast.FileTypeGmx:
+		return "MainEntry"
+	default:
+		if isMod {
+			return "init"
+		}
+		return "main"
+	}
+}
+
 func loadFile(ctx *pkgCtx, f *ast.File) {
 	for _, decl := range f.Decls {
 		switch d := decl.(type) {
@@ -563,6 +577,9 @@ func preloadFile(p *gox.Package, parent *pkgCtx, file string, f *ast.File, targe
 	for _, decl := range f.Decls {
 		switch d := decl.(type) {
 		case *ast.FuncDecl:
+			if f.NoEntrypoint && d.Name.Name == "main" {
+				d.Name.Name = getEntrypoint(f.FileType, f.Name.Name != "main")
+			}
 			if ctx.classRecv != nil { // in class file (.spx/.gmx)
 				if d.Recv == nil {
 					d.Recv = ctx.classRecv
@@ -630,6 +647,11 @@ func preloadFile(p *gox.Package, parent *pkgCtx, file string, f *ast.File, targe
 							log.Println("==> Load > NewType", name)
 						}
 						decl := ctx.pkg.NewType(name)
+						if t.Doc != nil {
+							decl.SetComments(t.Doc)
+						} else if d.Doc != nil {
+							decl.SetComments(d.Doc)
+						}
 						ld.typInit = func() { // decycle
 							if debugLoad {
 								log.Println("==> Load > InitType", name)
@@ -717,6 +739,9 @@ func loadFunc(ctx *blockCtx, recv *types.Var, d *ast.FuncDecl) {
 		ctx.handleErr(err)
 		return
 	}
+	if d.Doc != nil {
+		fn.SetComments(d.Doc)
+	}
 	if body := d.Body; body != nil {
 		if recv != nil {
 			ctx.inits = append(ctx.inits, func() { // interface issue: #795
