@@ -54,11 +54,15 @@ func init() {
 }
 
 func gopClTest(t *testing.T, gopcode, expected string, cachefile ...string) {
+	gopClTestEx(t, "main", gopcode, expected, cachefile...)
+}
+
+func gopClTestEx(t *testing.T, pkgname, gopcode, expected string, cachefile ...string) {
 	cl.SetDisableRecover(true)
 	defer cl.SetDisableRecover(false)
 
 	fs := parsertest.NewSingleFileFS("/foo", "bar.gop", gopcode)
-	pkgs, err := parser.ParseFSDir(gblFset, fs, "/foo", nil, 0)
+	pkgs, err := parser.ParseFSDir(gblFset, fs, "/foo", nil, parser.ParseComments)
 	if err != nil {
 		scanner.PrintError(os.Stderr, err)
 		t.Fatal("ParseFSDir:", err)
@@ -71,8 +75,8 @@ func gopClTest(t *testing.T, gopcode, expected string, cachefile ...string) {
 		copy.PersistLoadPkgs = true
 		conf = *copy.Ensure()
 	}
-	bar := pkgs["main"]
-	pkg, err := cl.NewPackage("", bar, &conf)
+	bar := pkgs[pkgname]
+	pkg, err := cl.NewPackage("github.com/goplus/gop/cl", bar, &conf)
 	if err != nil {
 		t.Fatal("NewPackage:", err)
 	}
@@ -2335,9 +2339,15 @@ func ++(a foo) {
 	println("a++")
 }
 
+func (a foo) != (b foo) bool{
+	println("a!=b")	
+	return true
+}
+
 var a, b foo
 var c = a - b
 var d = -a       // TODO: -a have no return value!
+var e = a!=b
 `, `package main
 
 import fmt "fmt"
@@ -2353,6 +2363,10 @@ func (a foo) Gop_Sub(b foo) foo {
 	fmt.Println("a - b")
 	return foo{}
 }
+func (a foo) Gop_NE(b foo) bool {
+	fmt.Println("a!=b")
+	return true
+}
 func (a foo) Gop_Neg() {
 	fmt.Println("-a")
 }
@@ -2363,6 +2377,7 @@ func (a foo) Gop_Inc() {
 var a, b foo
 var c = a.Gop_Sub(b)
 var d = a.Gop_Neg()
+var e = a.Gop_NE(b)
 `)
 }
 
@@ -2404,11 +2419,15 @@ var a = math.Round(1.2)
 `)
 }
 
-func _TestLocalImport(t *testing.T) {
+func TestLocalImport(t *testing.T) {
 	gopClTest(t, `import "./internal/spx"
 
 var a = spx.TestIntValue
-`, `
+`, `package main
+
+import spx "github.com/goplus/gop/cl/internal/spx"
+
+var a = spx.TestIntValue
 `)
 }
 
@@ -3200,3 +3219,52 @@ func main() {
 }
 `)
 }
+
+func TestGoFuncInstr(t *testing.T) {
+	gopClTest(t, `package main
+
+//go:noinline
+//go:uintptrescapes
+func test(s string, p, q uintptr, rest ...uintptr) int {
+}`, `package main
+//go:noinline
+//go:uintptrescapes
+func test(s string, p uintptr, q uintptr, rest ...uintptr) int {
+}
+`)
+}
+
+func TestGoTypeInstr(t *testing.T) {
+	gopClTest(t, `package main
+
+//go:notinheap
+type S struct{ x int }
+`, `package main
+//go:notinheap
+type S struct {
+	x int
+}
+`)
+}
+
+func TestNoEntrypoint(t *testing.T) {
+	gopClTest(t, `println("init")
+`, `package main
+
+import fmt "fmt"
+
+func main() {
+	fmt.Println("init")
+}
+`)
+	gopClTestEx(t, "bar", `package bar
+println("init")
+`, `package bar
+
+import fmt "fmt"
+
+func init() {
+	fmt.Println("init")
+}
+`)
+}
