@@ -27,6 +27,10 @@ import (
 )
 
 func codeErrorTest(t *testing.T, msg, src string) {
+	codeErrorTestEx(t, "main", msg, src)
+}
+
+func codeErrorTestEx(t *testing.T, pkgname, msg, src string) {
 	fs := parsertest.NewSingleFileFS("/foo", "bar.gop", src)
 	pkgs, err := parser.ParseFSDir(gblFset, fs, "/foo", nil, 0)
 	if err != nil {
@@ -37,7 +41,7 @@ func codeErrorTest(t *testing.T, msg, src string) {
 	conf.NoFileLine = false
 	conf.WorkingDir = "/foo"
 	conf.TargetDir = "/foo"
-	bar := pkgs["main"]
+	bar := pkgs[pkgname]
 	_, err = cl.NewPackage("", bar, &conf)
 	if err == nil {
 		t.Fatal("no error?")
@@ -441,8 +445,7 @@ b := []int{2: a}
 }
 
 func TestErrMapLit(t *testing.T) {
-	codeErrorTest(t, // TODO: first column need correct
-		`./bar.gop:2:34: cannot use 1+2 (type untyped int) as type string in map key
+	codeErrorTest(t, `./bar.gop:2:21: cannot use 1+2 (type untyped int) as type string in map key
 ./bar.gop:3:27: cannot use "Go" + "+" (type untyped string) as type int in map value`,
 		`
 a := map[string]int{1+2: 2}
@@ -578,3 +581,31 @@ func TestErrBranchStmt(t *testing.T) {
 	fallthrough
 }`)
 }
+
+func TestErrNoEntrypoint(t *testing.T) {
+	codeErrorTest(t,
+		"./bar.gop:2:2: undefined: println1", `func main() {
+	println1 "hello"
+}
+`)
+	codeErrorTest(t,
+		"./bar.gop:1:1: undefined: println1", `println1 "hello"`)
+
+	codeErrorTest(t,
+		"./bar.gop:2:2: undefined: println1", `
+	println1 "hello"
+`)
+	codeErrorTest(t,
+		"./bar.gop:2:2: undefined: println1", `package main
+	println1 "hello"
+`)
+	codeErrorTest(t,
+		`./bar.gop:1:9: undefined: abc`,
+		`println abc
+`)
+	codeErrorTestEx(t, "bar",
+		`./bar.gop:2:9: undefined: abc`,
+		`package bar
+println abc
+`)
+}
