@@ -26,6 +26,8 @@ import (
 	"path/filepath"
 	"strings"
 
+	"github.com/qiniu/x/log"
+
 	"github.com/goplus/gop/cmd/internal/base"
 	"github.com/goplus/gop/format"
 )
@@ -114,7 +116,10 @@ func walk(path string, d fs.DirEntry, err error) error {
 }
 
 func runCmd(cmd *base.Command, args []string) {
-	flag.Parse(args)
+	err := flag.Parse(args)
+	if err != nil {
+		log.Fatalln("parse input arguments failed:", err)
+	}
 	narg := flag.NArg()
 	if narg < 1 {
 		cmd.Usage(os.Stderr)
