@@ -35,9 +35,10 @@ type parser struct {
 	scanner scanner.Scanner
 
 	// Tracing/debugging
-	mode   Mode // parsing mode
-	trace  bool // == (mode & Trace != 0)
-	indent int  // indentation used for tracing output
+	mode         Mode // parsing mode
+	trace        bool // == (mode & Trace != 0)
+	noEntrypoint bool // no entrypoint func
+	indent       int  // indentation used for tracing output
 
 	// Comments
 	comments    []*ast.CommentGroup
@@ -2858,8 +2859,10 @@ func (p *parser) parseStmt() (s ast.Stmt) {
 	}
 
 	switch p.tok {
-	case token.CONST, token.TYPE, token.VAR:
-		s = &ast.DeclStmt{Decl: p.parseDecl(stmtStart)}
+	case token.TYPE:
+		s = &ast.DeclStmt{Decl: p.parseGenDecl(p.tok, p.parseTypeSpec)}
+	case token.CONST, token.VAR:
+		s = &ast.DeclStmt{Decl: p.parseGenDecl(p.tok, p.parseValueSpec)}
 	case
 		// tokens that may start an expression
 		token.IDENT, token.INT, token.FLOAT, token.IMAG, token.RAT, token.CHAR, token.STRING, token.FUNC, token.LPAREN, // operands
@@ -3067,7 +3070,11 @@ func (p *parser) parseGenDecl(keyword token.Token, f parseSpecFunction) *ast.Gen
 	}
 }
 
-func (p *parser) parseFuncDecl() *ast.FuncDecl {
+func isOverloadOps(tok token.Token) bool {
+	return int(tok) < len(overloadOps) && overloadOps[tok] != 0
+}
+
+func (p *parser) parseFuncDeclOrCall() (*ast.FuncDecl, *ast.CallExpr) {
 	if p.trace {
 		defer un(trace(p, "FunctionDecl"))
 	}
@@ -3076,19 +3083,68 @@ func (p *parser) parseFuncDecl() *ast.FuncDecl {
 	pos := p.expect(token.FUNC)
 	scope := ast.NewScope(p.topScope) // function scope
 
-	var recv *ast.FieldList
-	if p.tok == token.LPAREN {
-		recv = p.parseParameters(scope, false)
+	var recv, params, results *ast.FieldList
+	var ident *ast.Ident
+	var isOp, isFunLit, ok bool
+
+	if p.tok != token.LPAREN { // func identOrOp(...)
+		ident, isOp = p.parseIdentOrOp()
+		params, results = p.parseSignature(scope)
+	} else {
+		// method: func (recv) XXX(params) results { ... }
+		// funlit: func (params) results { ... }()
+		params = p.parseParameters(scope, true)
+		if p.tok == token.LPAREN {
+			// func (params) (results) { ... }()
+			isFunLit, results = true, p.parseParameters(scope, false)
+		} else if isOp = isOverloadOps(p.tok); isOp {
+			oldtok, oldpos := p.tok, p.pos
+			p.next()
+			if p.tok == token.LPAREN {
+				// func (recv) op(params) results { ... }
+				recv, ident = params, &ast.Ident{NamePos: oldpos, Name: oldtok.String()}
+				params, results = p.parseSignature(scope)
+			} else {
+				// func (params) typ { ... }()
+				p.unget(oldpos, oldtok, "")
+				typ := p.tryType()
+				if typ == nil {
+					panic("TODO: invalid result type")
+				}
+				isFunLit, results = true, &ast.FieldList{List: []*ast.Field{{Type: typ}}}
+			}
+		} else if typ := p.tryType(); typ == nil {
+			// func (params) { ... }()
+			isFunLit = true
+		} else if ident, ok = typ.(*ast.Ident); ok && p.tok == token.LPAREN {
+			// func (recv) ident(params) results { ... }
+			recv = params
+			params, results = p.parseSignature(scope)
+		} else {
+			// func (params) typ { ... }()
+			isFunLit, results = true, &ast.FieldList{List: []*ast.Field{{Type: typ}}}
+		}
+		if isFunLit {
+			body := p.parseBody(scope)
+			funLit := &ast.FuncLit{
+				Type: &ast.FuncType{
+					Func:    pos,
+					Params:  params,
+					Results: results,
+				},
+				Body: body,
+			}
+			call := p.parseCallOrConversion(funLit, false)
+			p.expectSemi()
+			return nil, call
+		}
 	}
 
-	ident, isOp := p.parseIdentOrOp()
-	params, results := p.parseSignature(scope)
 	if isOp {
 		if params == nil || len(params.List) != 1 {
 			log.Panicln("TODO: overload operator can only have one parameter")
 		}
 	}
-
 	var body *ast.BlockStmt
 	if p.tok == token.LBRACE {
 		body = p.parseBody(scope)
@@ -3131,7 +3187,7 @@ func (p *parser) parseFuncDecl() *ast.FuncDecl {
 	if debugParseOutput {
 		log.Printf("ast.FuncDecl{Name: %v, ...}\n", ident.Name)
 	}
-	return decl
+	return decl, nil
 }
 
 func (p *parser) parseDecl(sync map[token.Token]bool) ast.Decl {
@@ -3143,26 +3199,48 @@ func (p *parser) parseDecl(sync map[token.Token]bool) ast.Decl {
 	switch p.tok {
 	case token.CONST, token.VAR:
 		f = p.parseValueSpec
-
 	case token.TYPE:
 		f = p.parseTypeSpec
-
 	case token.FUNC:
-		decl := p.parseFuncDecl()
-		if p.errors.Len() != 0 {
-			p.errorExpected(pos, "declaration", 2)
-			p.advance(sync)
+		decl, call := p.parseFuncDeclOrCall()
+		if decl != nil {
+			if p.errors.Len() != 0 {
+				p.errorExpected(pos, "declaration", 2)
+				p.advance(sync)
+			}
+			return decl
 		}
-		return decl
+		return p.parseGlobalStmts(sync, pos, &ast.ExprStmt{X: call})
 	default:
-		p.errorExpected(pos, "declaration", 2)
-		p.advance(sync)
-		return &ast.BadDecl{From: pos, To: p.pos}
+		return p.parseGlobalStmts(sync, pos)
 	}
-
 	return p.parseGenDecl(p.tok, f)
 }
 
+func (p *parser) parseGlobalStmts(sync map[token.Token]bool, pos token.Pos, stmts ...ast.Stmt) *ast.FuncDecl {
+	p.topScope = ast.NewScope(p.topScope)
+	doc := p.leadComment
+	p.openLabelScope()
+	list := p.parseStmtList()
+	p.closeLabelScope()
+	p.closeScope()
+	if stmts != nil {
+		list = append(stmts, list...)
+	}
+	p.noEntrypoint = true
+	if p.errors.Len() != 0 { // TODO: error
+		p.advance(sync)
+	}
+	return &ast.FuncDecl{
+		Name: &ast.Ident{NamePos: pos, Name: "main"},
+		Doc:  doc,
+		Type: &ast.FuncType{
+			Params: &ast.FieldList{},
+		},
+		Body: &ast.BlockStmt{List: list},
+	}
+}
+
 // ----------------------------------------------------------------------------
 // Source files
 
@@ -3177,21 +3255,30 @@ func (p *parser) parseFile() *ast.File {
 		return nil
 	}
 
+	var noPkgDecl bool
 	// package clause
 	doc := p.leadComment
-	pos := p.expect(token.PACKAGE)
-	// Go spec: The package clause is not a declaration;
-	// the package name does not appear in any scope.
-	ident := p.parseIdent()
-	if ident.Name == "_" && p.mode&DeclarationErrors != 0 {
-		p.error(p.pos, "invalid package name _")
-	}
-	p.expectSemi()
+	var pos token.Pos
+	var ident *ast.Ident
+	if p.tok == token.PACKAGE {
+		pos = p.expect(token.PACKAGE)
+		// Go spec: The package clause is not a declaration;
+		// the package name does not appear in any scope.
+		ident = p.parseIdent()
+		if ident.Name == "_" && p.mode&DeclarationErrors != 0 {
+			p.error(p.pos, "invalid package name _")
+		}
+		p.expectSemi()
 
-	// Don't bother parsing the rest if we had errors parsing the package clause.
-	// Likely not a Go source file at all.
-	if p.errors.Len() != 0 {
-		return nil
+		// Don't bother parsing the rest if we had errors parsing the package clause.
+		// Likely not a Go source file at all.
+		if p.errors.Len() != 0 {
+			return nil
+		}
+	} else {
+		noPkgDecl = true
+		pos = token.NoPos
+		ident = ast.NewIdent("main")
 	}
 
 	p.openScope()
@@ -3227,13 +3314,15 @@ func (p *parser) parseFile() *ast.File {
 	}
 
 	return &ast.File{
-		Doc:        doc,
-		Package:    pos,
-		Name:       ident,
-		Decls:      decls,
-		Scope:      p.pkgScope,
-		Imports:    p.imports,
-		Unresolved: p.unresolved[0:i],
-		Comments:   p.comments,
+		Doc:          doc,
+		Package:      pos,
+		Name:         ident,
+		Decls:        decls,
+		Scope:        p.pkgScope,
+		Imports:      p.imports,
+		Unresolved:   p.unresolved[0:i],
+		Comments:     p.comments,
+		NoEntrypoint: p.noEntrypoint,
+		NoPkgDecl:    noPkgDecl,
 	}
 }
