@@ -77,9 +77,14 @@ ast.GenDecl:
           Kind: STRING
           Value: "io"
 ast.FuncDecl:
+  Doc:
+    ast.CommentGroup:
+      List:
+        ast.Comment:
+          Text: // comment
   Name:
     ast.Ident:
-      Name: init
+      Name: main
   Type:
     ast.FuncType:
       Params:
