@@ -1092,11 +1092,9 @@ func (p *printer) expr1(expr ast.Expr, prec1, depth int) {
 		if x.Last != nil {
 			p.expr(x.Last)
 		}
-		if x.Colon2 != token.NoPos {
+		if x.Expr3 != nil {
 			p.print(token.COLON)
-			if x.Expr3 != nil {
-				p.expr(x.Expr3)
-			}
+			p.expr(x.Expr3)
 		}
 
 	default:
@@ -1895,20 +1893,20 @@ func (p *printer) funcBodyUnnamed(headerSize int, sep whiteSpace, b *ast.BlockSt
 	}(p.level)
 	p.level = 0
 
-	const maxSize = 100
-	if headerSize+p.bodySize(b, maxSize) <= maxSize {
-		if len(b.List) > 0 {
-			p.print(blank)
-			for i, s := range b.List {
-				if i > 0 {
-					p.print(token.SEMICOLON, blank)
-				}
-				p.stmt(s, i == len(b.List)-1)
-			}
-			p.print(blank)
-		}
-		return
-	}
+	// const maxSize = 100
+	// if headerSize+p.bodySize(b, maxSize) <= maxSize {
+	// 	if len(b.List) > 0 {
+	// 		p.print(blank)
+	// 		for i, s := range b.List {
+	// 			if i > 0 {
+	// 				p.print(token.SEMICOLON, blank)
+	// 			}
+	// 			p.stmt(s, i == len(b.List)-1)
+	// 		}
+	// 		p.print(blank)
+	// 	}
+	// 	return
+	// }
 
 	/*	if sep != ignore {
 			//	p.print(blank) // always use blank
@@ -2039,11 +2037,7 @@ func (p *printer) declList(list []ast.Decl) {
 
 func (p *printer) file(src *ast.File) {
 	if src.NoEntrypoint {
-		if src.Name.Name == "main" {
-			p.unnamedFuncName = "main"
-		} else {
-			p.unnamedFuncName = "init"
-		}
+		p.unnamedFuncName = "main"
 	}
 	p.setComment(src.Doc)
 	if !src.NoPkgDecl {
